@@ -77,7 +77,7 @@ def IntegralLattice(data, basis=None):
 
     A lattice is a finitely generated free abelian group `L \cong \ZZ^r`
     equipped with a non-degenerate, symmetric bilinear form
-    `L \times L \colon \rightarrow \ZZ`. Here, lattices have an
+    `L \times L \to \ZZ`. Here, lattices have an
     ambient quadratic space `\QQ^n` and a distinguished basis.
 
     INPUT:
@@ -94,7 +94,7 @@ def IntegralLattice(data, basis=None):
       * the string ``'U'`` or ``'H'`` -- for hyperbolic lattices
 
     - ``basis`` -- (optional) a matrix whose rows form a basis of the
-      lattice,  or a list of module elements forming a basis
+      lattice, or a list of module elements forming a basis
 
     OUTPUT:
 
@@ -1272,34 +1272,46 @@ class FreeQuadraticModule_integer_symmetric(FreeQuadraticModule_submodule_with_b
             [1 0]
             [0 1]
             )
+
+        We can handle the trivial sublattice::
+
+            sage: # needs sage.graphs
+            sage: A1 = IntegralLattice("A1")
+            sage: L = A1.sublattice([])
+            sage: L.orthogonal_group()                                                  # needs sage.libs.gap
+            Group of isometries with 1 generator ([1],)
         """
         from sage.categories.groups import Groups
         from sage.groups.matrix_gps.isometries import GroupOfIsometries
-        sig = self.signature_pair()
-        if gens is None:
+
+        if gens is None and self.rank() == 0: # trivial lattice
             gens = []
-            if sig[1] == 0 or sig[0] == 0:  # definite
-                from sage.quadratic_forms.quadratic_form import QuadraticForm
-                is_finite = True
-                # Compute transformation matrix to the ambient module.
-                L = self.overlattice(self.ambient_module().gens())
-                Orthogonal = L.orthogonal_complement(self)
-                B = self.basis_matrix().stack(Orthogonal.basis_matrix())
-                if sig[0] == 0:  # negative definite
-                    q = QuadraticForm(ZZ, -2*self.gram_matrix())
-                else:  # positive definite
-                    q = QuadraticForm(ZZ, 2*self.gram_matrix())
-                identity = matrix.identity(Orthogonal.rank())
-                for g in q.automorphism_group().gens():
-                    g = g.matrix().T
-                    # We continue g as identity on the orthogonal complement.
-                    g = matrix.block_diagonal([g, identity])
-                    g = B.inverse()*g*B
-                    gens.append(g)
-            else:  # indefinite
+            is_finite = True
+        if gens is None:
+            sig = self.signature_pair()
+            if not (sig[1] == 0 or sig[0] == 0):  # indefinite
                 raise NotImplementedError(
                     "currently, we can only compute generators "
                     "for orthogonal groups over definite lattices.")
+
+            # definite
+            from sage.quadratic_forms.quadratic_form import QuadraticForm
+            is_finite = True
+            # Compute transformation matrix to the ambient module.
+            L = self.overlattice(self.ambient_module().gens())
+            Orthogonal = L.orthogonal_complement(self)
+            direct_sum_basis = self.basis_matrix().stack(Orthogonal.basis_matrix())
+            if sig[0] == 0:  # negative definite
+                q = QuadraticForm(ZZ, -2*self.gram_matrix())
+            else:  # positive definite
+                q = QuadraticForm(ZZ, 2*self.gram_matrix())
+            identity = matrix.identity(Orthogonal.rank())
+            gens = []
+            for g in q.automorphism_group().gens():
+                # We lift the automorphism by living the orthogonal complement invariant
+                g_directsum = matrix.block_diagonal([g.matrix().T, identity])
+                g_on_L = direct_sum_basis.inverse()*g_directsum*direct_sum_basis
+                gens.append(g_on_L)
         deg = self.degree()
         base = self.ambient_vector_space().base_ring()
         inv_bil = self.inner_product_matrix()
@@ -1424,7 +1436,7 @@ class FreeQuadraticModule_integer_symmetric(FreeQuadraticModule_submodule_with_b
         EXAMPLES::
 
             sage: L = IntegralLattice('A2')                                             # needs sage.graphs
-            sage: L.minimum()                                                           # needs sage.graphs
+            sage: L.minimum()                                                           # needs sage.graphs sage.libs.pari
             2
             sage: L.twist(-1).minimum()                                                 # needs sage.graphs
             -Infinity
@@ -1567,14 +1579,10 @@ class FreeQuadraticModule_integer_symmetric(FreeQuadraticModule_submodule_with_b
         """
         L = self.LLL()
         dim = L.dimension()
-        gram = L.gram_matrix()
         basis = L.basis_matrix()
 
         import fpylll
-        gmat = fpylll.IntegerMatrix(dim, dim)
-        for i in range(dim):
-            for j in range(dim):
-                gmat[i, j] = gram[i, j]
+        gmat = fpylll.IntegerMatrix.from_matrix(L.gram_matrix())
         gso = fpylll.GSO.Mat(gmat, gram=True)
         ok = gso.update_gso()
         assert ok
