@@ -59,7 +59,8 @@ the group invariants, and element orders, can be computed::
     sage: cl2 * cl2.order() == Cl.zero()
     True
     sage: Cl.abelian_group()
-    Additive abelian group isomorphic to Z/21 embedded in Form Class Group of Discriminant -431
+    Additive abelian group isomorphic to Z/21 embedded in
+    Form Class Group of Discriminant -431
     sage: Cl.gens()  # random
     [Class of 5*x^2 + 3*x*y + 22*y^2]
     sage: Cl.gens()[0].order()
@@ -90,11 +91,8 @@ from sage.categories.morphism import Morphism
 
 from sage.misc.prandom import randrange
 from sage.rings.integer_ring import ZZ
-from sage.rings.finite_rings.integer_mod_ring import Zmod
 from sage.rings.finite_rings.integer_mod import Mod
-from sage.rings.polynomial.polynomial_ring import polygen
 from sage.arith.misc import random_prime
-from sage.matrix.constructor import matrix
 from sage.groups.generic import order_from_multiple, multiple
 from sage.groups.additive_abelian.additive_abelian_wrapper import AdditiveAbelianGroupWrapper
 from sage.quadratic_forms.binary_qf import BinaryQF
@@ -128,7 +126,7 @@ class BQFClassGroup(Parent, UniqueRepresentation):
         Form Class Group of Discriminant -484
     """
 
-    def __init__(self, D, *, check=True):
+    def __init__(self, D, *, check=True) -> None:
         r"""
         Construct the class group for a given discriminant `D`.
 
@@ -163,7 +161,8 @@ class BQFClassGroup(Parent, UniqueRepresentation):
             Class of 16*x^2 + 5*x*y + 16*y^2
         """
         if isinstance(F, BQFClassGroup_element):
-            if check and F.parent() is not self:  # class group is unique parent
+            if check and F.parent() is not self:
+                # class group is unique parent
                 raise ValueError('quadratic form has incorrect discriminant')
             return F
         if F == 0:
@@ -174,8 +173,10 @@ class BQFClassGroup(Parent, UniqueRepresentation):
 
     def zero(self):
         r"""
-        Return the neutral element of this group, i.e., the class of the
-        principal binary quadratic form of the respective discriminant.
+        Return the neutral element of this group.
+
+        This is the class of the principal binary quadratic form of
+        the respective discriminant.
 
         EXAMPLES::
 
@@ -223,7 +224,7 @@ class BQFClassGroup(Parent, UniqueRepresentation):
             b = -b
         return self(BinaryQF([a, b, c]))
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         r"""
         Return a hash value for this form class group.
 
@@ -234,7 +235,7 @@ class BQFClassGroup(Parent, UniqueRepresentation):
         """
         return hash(('BQFClassGroup', self._disc))
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         r"""
         Return a string describing this form class group.
 
@@ -304,7 +305,8 @@ class BQFClassGroup(Parent, UniqueRepresentation):
             sage: Cl.order()                                                            # needs sage.rings.number_field
             16
             sage: G = Cl.abelian_group(); G
-            Additive abelian group isomorphic to Z/4 + Z/2 + Z/2 embedded in Form Class Group of Discriminant -3108
+            Additive abelian group isomorphic to Z/4 + Z/2 + Z/2 embedded in
+            Form Class Group of Discriminant -3108
             sage: G.gens()  # random
             (Class of 11*x^2 + 4*x*y + 71*y^2,
              Class of 6*x^2 + 6*x*y + 131*y^2,
@@ -319,7 +321,7 @@ class BQFClassGroup(Parent, UniqueRepresentation):
         gens = [BinaryQF(g) for g in gens]
         return AdditiveAbelianGroupWrapper(self, gens, ords)
 
-    def gens(self) -> list:
+    def gens(self) -> tuple:
         r"""
         Return a generating set of this form class group.
 
@@ -327,17 +329,17 @@ class BQFClassGroup(Parent, UniqueRepresentation):
 
             sage: Cl = BQFClassGroup(-4*419)
             sage: Cl.gens()
-            [Class of 3*x^2 + 2*x*y + 140*y^2]
+            (Class of 3*x^2 + 2*x*y + 140*y^2,)
 
         ::
 
             sage: Cl = BQFClassGroup(-4*777)
             sage: Cl.gens()  # random
-            [Class of 11*x^2 + 4*x*y + 71*y^2,
+            (Class of 11*x^2 + 4*x*y + 71*y^2,
              Class of 6*x^2 + 6*x*y + 131*y^2,
-             Class of 2*x^2 + 2*x*y + 389*y^2]
+             Class of 2*x^2 + 2*x*y + 389*y^2)
         """
-        return [g.element() for g in self.abelian_group().gens()]
+        return tuple(g.element() for g in self.abelian_group().gens())
 
     def _coerce_map_from_(self, other):
         r"""
@@ -350,7 +352,7 @@ class BQFClassGroup(Parent, UniqueRepresentation):
 
             sage: G = BQFClassGroup(-4*117117)
             sage: H = BQFClassGroup(-4*77)
-            sage: proj = G.hom(H); proj  # implicit doctest
+            sage: proj = G.hom(H); proj  # indirect doctest
             Coercion morphism:
               From: Form Class Group of Discriminant -468468
               To:   Form Class Group of Discriminant -308
@@ -381,7 +383,7 @@ class BQFClassGroup_element(AdditiveGroupElement):
     EXAMPLES::
 
         sage: F = BinaryQF([22, 91, 99])
-        sage: F.form_class()  # implicit doctest
+        sage: F.form_class()  # indirect doctest
         Class of 5*x^2 - 3*x*y + 22*y^2
 
     ::
@@ -389,11 +391,11 @@ class BQFClassGroup_element(AdditiveGroupElement):
         sage: Cl = BQFClassGroup(-4*419)
         sage: Cl.zero()
         Class of x^2 + 419*y^2
-        sage: Cl.gens()[0]  # implicit doctest
+        sage: Cl.gens()[0]  # indirect doctest
         Class of 3*x^2 + 2*x*y + 140*y^2
     """
 
-    def __init__(self, F, parent, *, check=True, reduce=True):
+    def __init__(self, F, parent, *, check=True, reduce=True) -> None:
         r"""
         Constructor for classes of binary quadratic forms.
 
@@ -520,7 +522,7 @@ class BQFClassGroup_element(AdditiveGroupElement):
 
     __rmul__ = __mul__
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         r"""
         Test two form classes for equality.
 
@@ -540,7 +542,7 @@ class BQFClassGroup_element(AdditiveGroupElement):
         # as well as hashing.
         return self._form == other._form
 
-    def __ne__(self, other):
+    def __ne__(self, other) -> bool:
         r"""
         Test two form classes for inequality.
 
@@ -556,7 +558,7 @@ class BQFClassGroup_element(AdditiveGroupElement):
         """
         return self._form != other._form
 
-    def __lt__(self, other):
+    def __lt__(self, other) -> bool:
         r"""
         Compare two form classes according to the lexicographic ordering
         on their coefficient lists.
@@ -604,7 +606,7 @@ class BQFClassGroup_element(AdditiveGroupElement):
         """
         return not self
 
-    def __repr__(self) -> str:
+    def _repr_(self) -> str:
         r"""
         Return a string representation of this form class.
 
@@ -616,7 +618,7 @@ class BQFClassGroup_element(AdditiveGroupElement):
         """
         return f'Class of {self._form}'
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         r"""
         Return a hash value for this form class.
 
@@ -704,7 +706,7 @@ class BQFClassGroupQuotientMorphism(Morphism):
         sage: proj(elt) == proj2(proj1(elt))
         True
     """
-    def __init__(self, G, H):
+    def __init__(self, G, H) -> None:
         r"""
         Initialize this morphism between class groups of binary
         quadratic forms.
